""" Macaulay2 Kernel for Jupyter
"""

from .kernel import M2Kernel
from ._version import __version__
